==> tiki-9.7.tar.bz2: tiki-9.7/lang/sq/language.php <==
<?php


$lang = array(
"Type" => "Lloj",
"Comment" => "Koment",
"Source" => "Burim",
"Forums" => "Forume",
"Date" => "Dat&euml;",
"Edit" => "P&euml;rpunoni",
"Action" => "Veprim",
"Sort" => "Rend",
"Search" => "K&euml;rkim",
"User" => "P&euml;rdorues",
"Language" => "Gjuh&euml;",
"Page" => "Faqe",
"Style" => "Stil",
"Top" => "Kryet",
"Forum" => "Forum",
"Score" => "Pik&euml;",
"User Watches" => "V&euml;zhgimet e p&euml;rdoruesit",
"Print" => "Shtype",
"History" => "Historik",
"Country" => "Vend",
"Last login" => "Hyrja e fundit",
"Email address" => "Vendndodhje email",
"Displayed time zone" => "Zon&euml; kohore e shfaqur",
"Number of visited pages to remember" => "Num&euml;r faqesh t&euml; vizituara q&euml; do t&euml; mbahen mend",
"User information" => "T&euml; dh&euml;na p&euml;rdoruesi",
"Use double-click to edit pages" => "P&euml;r p&euml;rpunimin e faqeve p&euml;rdorni dyklikimin",
"Last editor" => "P&euml;rpunuesi i fundit",
"Page last modified on" => "Faqja u ndryshua s&euml; fundmi m&euml;",
"Actions" => "Veprime",
"Prev" => "M&euml;pa",
"Next" => "Pasuesja",
"Object" => "Objekt",
"Dynamic Content" => "P&euml;rmbajtje Dinamike",
"and" => "dhe",
"User Preferences" => "Parap&euml;lqime P&euml;rdoruesi",
"Preferences" => "Parap&euml;lqime",
"Real Name" => "Emri i V&euml;rtet&euml;",
"Vote" => "Vot&euml;",
"Categorize" => "Kategori",
"Watches" => "V&euml;zhgime",
"More..." => "M&euml; tep&euml;r...",
"Post new comment" => "Postoni koment t&euml; ri",
"posts" => "postime",
"Threshold" => "Prag",
"Search:" => "K&euml;rkim",
"Go back" => "Kthehuni mbrapsht",
"Return to home page" => "Kthehuni te faqja hyr&euml;se",
"Folksonomy Tags" => "Etiketa Folksonomie",
"New name" => "Em&euml;r i ri",
"Legend:" => "Legjend&euml;:",
"v=view" => "v=shiheni",
"Ip" => "Ip",
"Logged in as" => "Futur si",
"Log out" => "Dilni",
"None match your" => "Nuk u gjet asnj&euml; p&euml;rputhje me",
"preferred languages" => "gjuh&euml;t e parap&euml;lqyera",
"Last modification" => "Ndryshimi i fundit",
"View page" => "Shihni faqen",
"Home" => "Hyrje",
"Event" => "P&euml;r &ccedil;far&euml;",
"Jan" => "Jan.",
"Feb" => "Feb.",
"Mar" => "March",
"Apr" => "April",
"Jun" => "June",
"Jul" => "July",
"Aug" => "Aug.",
"Sep" => "Sept.",
"Oct" => "Oct.",
"Nov" => "Nov.",
"New password" => "Fjal&euml;kalim i ri",
"Select the language to edit" => "P&euml;rzgjidhni gjuh&euml;n p&euml;r p&euml;rpunim",
"Add a translation" => "Shtoni nj&euml; p&euml;rkthim",
"Edit translations" => "P&euml;rpunoni p&euml;rkthime",
"Original" => "Origjinali",
"Monitor this page" => "Mbik&euml;qyre k&euml;t&euml; faqe",
"Upload picture" => "Ngarkoni pamje",
"Add another image" => "Shtoni pamje tjet&euml;r",
"Use rating" => "P&euml;rdor vler&euml;sim",
"Translate:" => "P&euml;rktheni:",
"Tag translation" => "P&euml;rkthim etiketash",
"Note that tags that were created on pages with no language set will remain\n\tuniversal (i.e. is the same tag in all languages) until a language has been set for the tag." => "Kujdes: Etiketat e krijuara n&euml; faqe pa gjuh&euml; t&euml; p&euml;rcaktuar, do t&euml; mbesin universale (d.m.th. e nj&euml;jta etiket&euml; n&euml; t&euml;r&euml; gjuh&euml;t) deri ku t&euml; caktohet nj&euml; gjuh&euml; p&euml;r etiket&euml;n.",
"Until then, they cannot be translated." => "Deri at&euml;her&euml;, nuk mund t&euml; p&euml;rkthehen.",
"Show checkboxes to clear language information on tags" => "Shfaq kutiza shenje p&euml;r fshirje t&euml; dh&euml;nash gjuhe mbi etiketat",
"Set language" => "Caktoni gjuh&euml;",
"Show the following languages" => "Shfaq gjuh&euml;t vijuese",
"Date of post" => "Dat&euml; postimi",
"(current)" => "(i tanishmi)",
"Source of version" => "Burimi i versionit",
"s=source" => "s=burimi",
"Hide translation history" => "Fshihe historikun e p&euml;rkthimit",
"Show translation history" => "Shfaq historik p&euml;rkthimi",
"Pick user Avatar" => "Zgjidhni nj&euml; Avatar p&euml;rdoruesi",
"Rename page" => "Riem&euml;rtoni faqen",
"Contributors to this page" => "Pjes&euml;marr&euml;s n&euml; k&euml;t&euml; faqe",
"Personal Information" => "T&euml; dh&euml;na personale",
"Is email public? (uses scrambling to prevent spam)" => "A &euml;sht&euml; email publik? (p&euml;r t&euml; parandaluar mesazhet hedhurina p&euml;rdoret maskim)",
"Does your mail reader need a special charset" => "Zgjidhni kodim g&euml;rmash p&euml;r lexuesin e post&euml;s",
"Account Information" => "T&euml; Dh&euml;na Llogarie",
"Leave \"New password\" and \"Confirm new password\" fields blank to keep current password" => "P&euml;r t&euml; mbajtur fjal&euml;kalimin e vjet&euml;r, l&euml;rini bosh fushat \"Fjal&euml;kalim i ri\" dhe \"Ripohoni fjal&euml;kalimin e ri\"",
"Confirm new password" => "Ripohoni fjal&euml;kalimin e ri",
"Current password (required)" => "Fjal&euml;kalimi n&euml; fuqi (e domosdoshme)",
"Show:" => "Mostra:",
"Show posts" => "Shfaq postimet",
);

==> tiki-19.1.tar.bz2: tiki-19.1/lang/sq/language.php <==
<?php



$lang = array(
"Type" => "Lloj",
"Comment" => "Koment",
"Source" => "Burim",
"Forums" => "Forume",
"Top" => "Kryet",
"Forum" => "Forum",
"Object" => "Objekt",
"Edit" => "P&euml;rpunoni",
"User" => "P&euml;rdorues",
"Print" => "Shtype",
"Action" => "Veprim",
"Language" => "Gjuh&euml;",
"and" => "dhe",
"Search" => "K&euml;rkim",
"Actions" => "Veprime",
"Style" => "Stil",
"Score" => "Pik&euml;",
"History" => "Historik",
"Country" => "Vend",
"Last login" => "Hyrja e fundit",
"Page" => "Faqe",
"posts" => "postime",
"Displayed time zone" => "Zon&euml; kohore e shfaqur",
"Number of visited pages to remember" => "Num&euml;r faqesh t&euml; vizituara q&euml; do t&euml; mbahen mend",
"User information" => "T&euml; dh&euml;na p&euml;rdoruesi",
"Last editor" => "P&euml;rpunuesi i fundit",
"Page last modified on" => "Faqja u ndryshua s&euml; fundmi m&euml;",
"Next" => "Pasuesja",
"Dynamic Content" => "P&euml;rmbajtje Dinamike",
"Date" => "Dat&euml;",
"Prev" => "M&euml;pa",
"Sort" => "Rend",
"Email address" => "Vendndodhje email",
"User Preferences" => "Parap&euml;lqime P&euml;rdoruesi",
"Preferences" => "Parap&euml;lqime",
"Real Name" => "Emri i V&euml;rtet&euml;",
"Vote" => "Vot&euml;",
"Personal Information" => "T&euml; dh&euml;na personale",
"User Watches" => "V&euml;zhgimet e p&euml;rdoruesit",
"Categorize" => "Kategori",
"Watches" => "V&euml;zhgime",
"View page" => "Shihni faqen",
"More..." => "M&euml; tep&euml;r...",
"Post new comment" => "Postoni koment t&euml; ri",
"Threshold" => "Prag",
"Search:" => "K&euml;rkim",
"Go back" => "Kthehuni mbrapsht",
"Return to home page" => "Kthehuni te faqja hyr&euml;se",
"Original" => "Origjinali",
"New name" => "Em&euml;r i ri",
"Event" => "P&euml;r &ccedil;far&euml;",
"Home" => "Hyrje",
"Logged in as" => "Futur si",
"Log out" => "Dilni",
"None match your" => "Nuk u gjet asnj&euml; p&euml;rputhje me",
"preferred languages" => "gjuh&euml;t e parap&euml;lqyera",
"Last modification" => "Ndryshimi i fundit",
"New password" => "Fjal&euml;kalim i ri",
"Confirm new password" => "Ripohoni fjal&euml;kalimin e ri",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar" => "March",
"Apr." => "April",
"Aug." => "Aug.",
"Sep." => "Sept.",
"Oct." => "Oct.",
"Nov." => "Nov.",
"Add a translation" => "Shtoni nj&euml; p&euml;rkthim",
"Edit translations" => "P&euml;rpunoni p&euml;rkthime",
"Translate:" => "P&euml;rktheni:",
"Monitor this page" => "Mbik&euml;qyre k&euml;t&euml; faqe",
"Upload picture" => "Ngarkoni pamje",
"Add another image" => "Shtoni pamje tjet&euml;r",
"Tag translation" => "P&euml;rkthim etiketash",
"Set language" => "Caktoni gjuh&euml;",
"Ip" => "Ip",
"Date of post" => "Dat&euml; postimi",
"(current)" => "(i tanishmi)",
"Source of version" => "Burimi i versionit",
"Hide translation history" => "Fshihe historikun e p&euml;rkthimit",
"Show translation history" => "Shfaq historik p&euml;rkthimi",
"Pick user profile picture" => "Zgjidhni nj&euml; Avatar p&euml;rdoruesi",
"Rename page" => "Riem&euml;rtoni faqen",
"Contributors to this page" => "Pjes&euml;marr&euml;s n&euml; k&euml;t&euml; faqe",
"Account Information" => "T&euml; Dh&euml;na Llogarie",
"Leave \"New password\" and \"Confirm new password\" fields blank to keep current password" => "P&euml;r t&euml; mbajtur fjal&euml;kalimin e vjet&euml;r, l&euml;rini bosh fushat \"Fjal&euml;kalim i ri\" dhe \"Ripohoni fjal&euml;kalimin e ri\"",
"Current password (required)" => "Fjal&euml;kalimi n&euml; fuqi (e domosdoshme)",
"Show:" => "Mostra:",
"Show posts" => "Shfaq postimet",
"Is email public? (uses scrambling to prevent spam)" => "A &euml;sht&euml; email publik? (p&euml;r t&euml; parandaluar mesazhet hedhurina p&euml;rdoret maskim)",
"Does your email application need a special character set" => "Zgjidhni kodim g&euml;rmash p&euml;r lexuesin e post&euml;s",
);
